#  RESTful API with Python,SQLAlchemy, & FastAPI: Access and Refresh Tokens

In this article, you'll learn how to secure a FastAPI app by implementing access and refresh token functionalities using JSON Web Tokens (JWTs). We'll use the FastAPI JWT Auth package to sign, encode and decode the access and refresh JWT tokens.

![RESTful API with Python,SQLAlchemy, & FastAPI: Access and Refresh Tokens](https://codevoweb.com/wp-content/uploads/2022/07/RESTful-API-with-Python-FastAPI-Access-and-Refresh-Tokens.webp)

## Topics Covered

- Python FastAPI JWT Authentication Overview
- How to Setup FastAPI with PostgreSQL
    - Setup FastAPI
    - Initialize a Simple FastAPI Server
- Setting up Environment Variables in FastAPI
- Connect to the PostgreSQL Docker Container
- Installing the UUID OSSP PostgreSQL Extension
- Create Database Models with SQLAlchemy in FastAPI
- Creating Schemas with Pydantic in FastAPI
- Password Management with Bcrypt
- Configure the FastAPI JWT Auth Extension
- Creating the Authentication Controllers
    - User Registration Controller
    - User Sign-in Controller
    - Refresh Access Token Controller
    - Logout User Controller
- How to add Protected Routes
- Create a User Controller
- Adding the Routes to FastAPI Middleware Pipeline
- Database Migration with Alembic
- Testing the FastAPI JSON Web Token API

Read the entire article here: [https://codevoweb.com/restful-api-with-python-fastapi-access-and-refresh-tokens](https://codevoweb.com/restful-api-with-python-fastapi-access-and-refresh-tokens)

### 1. RESTful API with Python,SQLAlchemy, & FastAPI: Access and Refresh Tokens

[RESTful API with Python, SQLAlchemy, & FastAPI: Access and Refresh Tokens](https://codevoweb.com/restful-api-with-python-fastapi-access-and-refresh-tokens)

### 2. RESTful API with Python, SQLAlchemy, & FastAPI: Send HTML Emails

[RESTful API with Python, SQLAlchemy & FastAPI: Send HTML Emails](https://codevoweb.com/restful-api-with-python-fastapi-send-html-emails)

### 3. CRUD RESTful API Server with Python, FastAPI, SQLAlchemy, and PostgreSQL

[CRUD RESTful API Server with Python, FastAPI, SQLAlchemy, and PostgreSQL](https://codevoweb.com/crud-restful-api-server-with-python-fastapi-and-postgresql)
